@@ -32,7 +32,6 @@ using namespace Kontact;
 #include <QAction>
 #include <QIcon>
 #include <KLocalizedString>
-#include <KStringHandler>
 #include <KIconLoader>
 
 #include <QDragEnterEvent>
@@ -165,7 +164,7 @@ public:
 
 private:
     QList<KontactInterface::Plugin *> pluginList;
-    Navigator *mNavigator;
+    Navigator *mNavigator = nullptr;
 };
 
 class SortFilterProxyModel
@@ -237,7 +236,7 @@ public:
     }
 
 private:
-    Navigator *mNavigator;
+    Navigator *mNavigator = nullptr;
 };
 
 }
