@@ -66,18 +66,15 @@ using namespace Kontact;
 #include <QDBusConnection>
 #include <QSplitter>
 #include <QStackedWidget>
-#include <QTimer>
 #include <QVBoxLayout>
 #include <QShortcut>
 #include <QIcon>
 #include <KHelpClient>
 #include <KSharedConfig>
 #include <QStandardPaths>
-#include <QFile>
 #include <QHBoxLayout>
 #include <QApplication>
 #include <KAboutData>
-#include <QFontDatabase>
 
 #include <grantleetheme/grantleethememanager.h>
 #include <grantleetheme/grantleetheme.h>
@@ -102,7 +99,7 @@ public:
     // We need to keep track of the plugins which are loaded, so pass a pointer
     // to the plugin list here. Be sure to reset it back to 0 with
     // setPluginList() as soon as the list gets destroyed.
-    ServiceStarter(PluginList *pluginList)
+    explicit ServiceStarter(PluginList *pluginList)
     {
         mPlugins = pluginList;
     }
@@ -258,7 +255,7 @@ void MainWindow::initObject()
     // done initializing
     slotShowStatusMsg(QString());
 
-    connect(KPIM::BroadcastStatus::instance(), SIGNAL(statusMsg(QString)), this, SLOT(slotShowStatusMsg(QString)));
+    connect(KPIM::BroadcastStatus::instance(), &KPIM::BroadcastStatus::statusMsg, this, &MainWindow::slotShowStatusMsg);
 
     // launch commandline specified module if any
     activateInitialPluginModule();
@@ -505,8 +502,8 @@ void MainWindow::loadPlugins()
         if (hasPartProp.isValid()) {
             plugin->setShowInSideBar(hasPartProp.toBool());
         }
-
-        for (i = 0; i < plugins.count(); ++i) {
+        const int nbPlugins{plugins.count()};
+        for (i = 0; i < nbPlugins; ++i) {
             KontactInterface::Plugin *p = plugins.at(i);
             if (plugin->weight() < p->weight()) {
                 break;
