@@ -41,10 +41,8 @@ IntroductionWebEnginePage::IntroductionWebEnginePage(QObject *parent)
     settings()->setAttribute(QWebEngineSettings::Accelerated2dCanvasEnabled, false);
     settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
     settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AllowRunningInsecureContent, false);
-#endif
     profile()->setPersistentCookiesPolicy(QWebEngineProfile::NoPersistentCookies);
 
 
