@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ public:
 Q_SIGNALS:
     void urlClicked(const QUrl &url);
 protected:
-    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) Q_DECL_OVERRIDE;
+    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
 };
 
 #endif // INTRODUCTIONWEBENGINEPAGE_H
